You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by gz...@apache.org on 2020/01/23 13:13:24 UTC

[camel] branch camel-3.0.x updated (edcb1cb -> 65d2324)

This is an automated email from the ASF dual-hosted git repository.

gzurowski pushed a change to branch camel-3.0.x
in repository https://gitbox.apache.org/repos/asf/camel.git.


    from edcb1cb  CAMEL-14424: HTTP responses over 4 MB fail (#3505)
     new e35ba39  Remove unneeded variables
     new f2bdb64  Replace md5 and sha1 with sha512 files
     new 4eebbbe  Publish XML schemas on new Camel website (Git repository)
     new 65d2324  [Minor] Update commit message

The 4 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 etc/scripts/release-distro.sh  | 26 ++++++++++++++------------
 etc/scripts/release-website.sh | 16 ++++++++--------
 2 files changed, 22 insertions(+), 20 deletions(-)


[camel] 03/04: Publish XML schemas on new Camel website (Git repository)

Posted by gz...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

gzurowski pushed a commit to branch camel-3.0.x
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 4eebbbed5d82fbaf871e9ccb39c2e54e550d2c8a
Author: Gregor Zurowski <gr...@zurowski.org>
AuthorDate: Thu Jan 23 14:02:34 2020 +0100

    Publish XML schemas on new Camel website (Git repository)
---
 etc/scripts/release-website.sh | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/etc/scripts/release-website.sh b/etc/scripts/release-website.sh
index 1d8eb1c..22f6486 100755
--- a/etc/scripts/release-website.sh
+++ b/etc/scripts/release-website.sh
@@ -29,7 +29,7 @@ COMPLIST=( "camel-spring:spring"
   "camel-blueprint:blueprint" )
 SITE_DIR="${DOWNLOAD}/websites/production/camel"
 WEBSITE_URL="https://svn.apache.org/repos/infra/websites/production/camel/content"
-
+GIT_WEBSITE_URL="https://gitbox.apache.org/repos/asf/camel-website.git"
 
 if [ -z "${VERSION}" -o ! -d "${DOWNLOAD}" ]
 then
@@ -60,9 +60,9 @@ done
 echo
 
 echo "################################################################################"
-echo "                           CHECKOUT SCHEMAS WEBSITE                             "
+echo "                           CHECKOUT CAMEL WEBSITE                               "
 echo "################################################################################"
-cd "${SITE_DIR}/${VERSION}" && svn co --non-interactive "${WEBSITE_URL}/schema/"
+cd "${SITE_DIR}/${VERSION}" && git clone "${GIT_WEBSITE_URL}"
 
 echo "################################################################################"
 echo "                           PUBLISH CAMEL SCHEMAS                                "
@@ -70,7 +70,7 @@ echo "##########################################################################
 for comp in ${COMPLIST[*]}; do
   src=${comp%:*}
   dest=${comp#*:}
-  cp ${DOWNLOAD}/${VERSION}/org/apache/camel/${src}/${VERSION}/*.xsd ${SITE_DIR}/${VERSION}/schema/${dest}/
+  cp ${DOWNLOAD}/${VERSION}/org/apache/camel/${src}/${VERSION}/*.xsd ${SITE_DIR}/${VERSION}/camel-website/static/schema/${dest}/
   # update_latest_released_schema("${SITE_DIR}/content/schema/${dest}/")
 done
 echo
@@ -98,10 +98,10 @@ echo "NOTE: Manual steps required! Check the schemas and manual files for new ar
 echo "      add them to the repository as required and commit your changes. This step"
 echo "      is intentionally not automated at this point to avoid errors."
 echo
-echo "cd ${SITE_DIR}/${VERSION}/schema/"
-echo "svn status"
-echo "svn add <schema-${VERSION}-qualifier>.xsd"
-echo "svn ci -m \"Uploading released schemas for camel-${VERSION}\""
+echo "cd ${SITE_DIR}/${VERSION}/camel-website/"
+echo "git status"
+echo "git add <schema-${VERSION}-qualifier>.xsd"
+echo "git commit -m \"Add XML schemas for camel-${VERSION}\""
 echo
 echo "cd ${SITE_DIR}/${VERSION}/manual/"
 echo "svn status"


[camel] 02/04: Replace md5 and sha1 with sha512 files

Posted by gz...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

gzurowski pushed a commit to branch camel-3.0.x
in repository https://gitbox.apache.org/repos/asf/camel.git

commit f2bdb6474cdafb69a36f92ed3acff4e716fa4248
Author: Gregor Zurowski <gr...@zurowski.org>
AuthorDate: Thu Jan 23 13:37:55 2020 +0100

    Replace md5 and sha1 with sha512 files
---
 etc/scripts/release-distro.sh | 18 ++++++++++++++----
 1 file changed, 14 insertions(+), 4 deletions(-)

diff --git a/etc/scripts/release-website.sh b/etc/scripts/release-website.sh
index 22f6486..d72ec57 100755
--- a/etc/scripts/release-website.sh
+++ b/etc/scripts/release-website.sh
@@ -101,7 +101,7 @@ echo
 echo "cd ${SITE_DIR}/${VERSION}/camel-website/"
 echo "git status"
 echo "git add <schema-${VERSION}-qualifier>.xsd"
-echo "git commit -m \"Add XML schemas for camel-${VERSION}\""
+echo "git commit -m \"Add XML schemas for Camel ${VERSION}\""
 echo
 echo "cd ${SITE_DIR}/${VERSION}/manual/"
 echo "svn status"


[camel] 01/04: Remove unneeded variables

Posted by gz...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

gzurowski pushed a commit to branch camel-3.0.x
in repository https://gitbox.apache.org/repos/asf/camel.git

commit e35ba39415a53c46f6c73ff9913725b9f9ba9e8a
Author: Gregor Zurowski <gr...@zurowski.org>
AuthorDate: Thu Jan 23 13:21:11 2020 +0100

    Remove unneeded variables
---
 etc/scripts/release-distro.sh | 8 --------
 1 file changed, 8 deletions(-)

diff --git a/etc/scripts/release-distro.sh b/etc/scripts/release-distro.sh
index 4ca67d7..43d9fa3 100755
--- a/etc/scripts/release-distro.sh
+++ b/etc/scripts/release-distro.sh
@@ -22,15 +22,7 @@ mkdir -p ${DOWNLOAD} 2>/dev/null
 
 # The following component contain schema definitions that must be published
 RUNDIR=$(cd ${0%/*} && echo $PWD)
-COMPLIST=( "camel-spring:spring"
-  "camel-cxf:cxf"
-  "camel-osgi:osgi"
-  "camel-spring-integration:spring/integration"
-  "camel-spring-security:spring-security"
-  "camel-blueprint:blueprint" )
 DIST_REPO="https://dist.apache.org/repos/dist/release/camel/apache-camel/"
-SITE_DIR="/www/camel.apache.org"
-
 
 if [ -z "${VERSION}" -o ! -d "${DOWNLOAD}" ]
 then
diff --git a/etc/scripts/release-distro.sh b/etc/scripts/release-distro.sh
index 43d9fa3..070c894 100755
--- a/etc/scripts/release-distro.sh
+++ b/etc/scripts/release-distro.sh
@@ -39,11 +39,21 @@ wget -e robots=off --wait 3 --no-check-certificate \
  -r -np "--reject=html,txt" "--follow-tags=" \
  -P "${DOWNLOAD}/${VERSION}" -nH "--cut-dirs=3" "--level=1" "--ignore-length" \
  "https://repository.apache.org/content/repositories/releases/org/apache/camel/apache-camel/${VERSION}/"
+
+DOWNLOAD_LOCATION="${DOWNLOAD}/${VERSION}/org/apache/camel/apache-camel/${VERSION}"
+
 # Remove duplicate signature files
-rm ${DOWNLOAD}/dist/${VERSION}/*.asc.asc
-# Remove the signature check sum files
-rm ${DOWNLOAD}/dist/${VERSION}/*.asc.md5
-rm ${DOWNLOAD}/dist/${VERSION}/*.asc.sha1
+rm "${DOWNLOAD_LOCATION}/"*.asc.asc
+
+# Remove the md5 and sha1 check sum files
+rm "${DOWNLOAD_LOCATION}/"*.md5
+rm "${DOWNLOAD_LOCATION}/"*.sha1
+
+# Create sha512 check sum files
+cd "${DOWNLOAD_LOCATION}"
+for file in *.pom *.tar.gz *.zip; do
+  sha512sum "${file}" > "${file}.sha512"
+done
 
 echo "################################################################################"
 echo "                         RESET GROUP PERMISSIONS                                "


[camel] 04/04: [Minor] Update commit message

Posted by gz...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

gzurowski pushed a commit to branch camel-3.0.x
in repository https://gitbox.apache.org/repos/asf/camel.git

commit 65d23246470a98d7ac7561ef122134955a0ab58c
Author: Gregor Zurowski <gr...@zurowski.org>
AuthorDate: Thu Jan 23 14:05:29 2020 +0100

    [Minor] Update commit message
---
 etc/scripts/release-website.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
